The EnergyScope model — EnergyScope_documentation 2.2 documentation

# The EnergyScope model

The EnergyScope project is an open-source whole-energy system for regional energy system. The model optimises the design and hourly operation over a year for a target year.

EnergyScope is mainly developped by EPFL (Switzerland) and UCLouvain (Belgium). See Releases section for acknowledgment, versions and publications.

# Downloading EnergyScope

The public version of EnergyScope can be downloaded in the Releases section or from its github repository (using the Clone or Download button on the right side of the screen): https://github.com/energyscope/EnergyScope

# Main contributors

- Stefano Moret (website): moret.stefano@gmail.com

- Gauthier Limpens : gauthierLimpens@gmail.com

# Contents

Contents:

- Releases
- Getting started
- Model formulation
- Data for the Belgian energy system
- Toolbox

# Indices and tables

- Index

- Module Index

- Search Page